
******

Bravo!  You have received a Medical Diploma in "debt" from   
the Orbital Convergence University International Air and Water Embassy of the Tangerine Planet.  

You are now officially certified to include "debt" in your practice.

******

# 🪙 debt

## 💳 obtain
`(ZSH) pip install debt`

## 📈 tutorial
`(ZSH) debt shares`




